==> com.liferay.dynamic.data.mapping.form.renderer-5.0.69.jar: META-INF/resources/js/components/AutoFocus.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@5.0.69/js/components/AutoFocus.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../hooks/usePage.es'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.AutoFocus = void 0;

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _usePage2 = require("../hooks/usePage.es");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var AutoFocus = function AutoFocus(_ref) {
      var children = _ref.children;
      var childRef = (0, _react.useRef)();

      var _usePage = (0, _usePage2.usePage)(),
          activePage = _usePage.activePage,
          containerElement = _usePage.containerElement;

      var _useState = (0, _react.useState)(0),
          _useState2 = _slicedToArray(_useState, 2),
          increment = _useState2[0],
          setIncrement = _useState2[1];

      (0, _react.useLayoutEffect)(function () {
        if (childRef.current && (containerElement === null || containerElement === void 0 ? void 0 : containerElement.current)) {
          if (childRef.current.querySelector('.loading-animation')) {
            /**
             * This hack is to update the variable increment and cause one
             * more render until all loadings are removed from the screen
             * and so the field will be ready to focus
             */
            setTimeout(function () {
              return setIncrement(function (value) {
                return value + 1;
              });
            }, 5);
          } else {
            if (!document.activeElement || !Liferay.ThemeDisplay.isControlPanel() && document.activeElement.querySelector('input') && document.activeElement.querySelector('input').type === 'hidden' || (containerElement === null || containerElement === void 0 ? void 0 : containerElement.current.parentNode.className.includes('ddm-form-builder-app'))) {
              removeTabs();
              var currentTitle = containerElement === null || containerElement === void 0 ? void 0 : containerElement.current.parentNode.getElementsByClassName('ddm-form-name')[0];
              scrollComponentToTop(currentTitle);
              var componentTitle = currentTitle === null || currentTitle === void 0 ? void 0 : currentTitle.innerHTML;
              var currentDescription = containerElement === null || containerElement === void 0 ? void 0 : containerElement.current.parentNode.getElementsByClassName('.ddm-form-description')[0];
              var componentDescription = currentDescription === null || currentDescription === void 0 ? void 0 : currentDescription.innerHTML;
              var currentPage = document.activeElement.querySelector('.ddm-layout-builder:not(.hide)');
              var firstInput = currentPage === null || currentPage === void 0 ? void 0 : currentPage.querySelector('input:not([type="hidden"])');
              var defaultTitle = Liferay.Language.get('untitled-form');

              if ((!componentTitle || componentTitle === defaultTitle) && !componentDescription && firstInput && !containerElement.current.contains(document.activeElement)) {
                firstInput.focus({
                  behavior: 'smooth',
                  preventScroll: false
                });

                if (firstInput.select) {
                  firstInput.select();
                }
              }

              scrollComponentToTop(currentTitle);
            }
          }
        }
      }, [activePage, childRef, containerElement, increment]);
      return (/*#__PURE__*/_react.default.cloneElement(children, {
          ref: function ref(node) {
            childRef.current = node;
          }
        })
      );
    };

    exports.AutoFocus = AutoFocus;

    function scrollComponentToTop(currentTitle) {
      if (currentTitle) {
        var _document$querySelect;

        var containerPosition = currentTitle.getBoundingClientRect();
        var menuSize = (_document$querySelect = document.querySelector('.control-menu-container')) === null || _document$querySelect === void 0 ? void 0 : _document$querySelect.clientHeight;
        window.scroll(containerPosition.x - menuSize, containerPosition.y - menuSize);
      }
    }

    function removeTabs() {
      var firstPageComponent = document.querySelector('div[class^="lfr-layout-structure-item');
      var formPortlet = firstPageComponent === null || firstPageComponent === void 0 ? void 0 : firstPageComponent.querySelector('.portlet-forms');

      if (!formPortlet) {
        var _document$querySelect2;

        (_document$querySelect2 = document.querySelectorAll('.ddm-form-name,.ddm-form-description,.lfr-ddm-form-page-title,.lfr-ddm-form-page-description')) === null || _document$querySelect2 === void 0 ? void 0 : _document$querySelect2.forEach(function (element) {
          return element.removeAttribute('tabindex');
        });
      }
    }
    //# sourceMappingURL=AutoFocus.es.js.map
  }
});
//# sourceMappingURL=AutoFocus.es.js.map

==> com.liferay.dynamic.data.mapping.form.renderer-5.0.73.jar: META-INF/resources/js/components/AutoFocus.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@5.0.73/js/components/AutoFocus.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../hooks/usePage.es'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.AutoFocus = void 0;

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _usePage2 = require("../hooks/usePage.es");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var AutoFocus = function AutoFocus(_ref) {
      var children = _ref.children;
      var childRef = (0, _react.useRef)();

      var _usePage = (0, _usePage2.usePage)(),
          activePage = _usePage.activePage,
          containerElement = _usePage.containerElement;

      var _useState = (0, _react.useState)(0),
          _useState2 = _slicedToArray(_useState, 2),
          increment = _useState2[0],
          setIncrement = _useState2[1];

      (0, _react.useLayoutEffect)(function () {
        if (childRef.current && (containerElement === null || containerElement === void 0 ? void 0 : containerElement.current)) {
          if (childRef.current.querySelector('.loading-animation')) {
            /**
             * This hack is to update the variable increment and cause one
             * more render until all loadings are removed from the screen
             * and so the field will be ready to focus
             */
            setTimeout(function () {
              return setIncrement(function (value) {
                return value + 1;
              });
            }, 5);
          } else {
            if (!document.activeElement) {
              var firstInput = childRef.current.querySelector('input');

              if (firstInput && !containerElement.current.contains(document.activeElement)) {
                firstInput.focus();

                if (firstInput.select) {
                  firstInput.select();
                }
              }
            }
          }
        }
      }, [activePage, childRef, containerElement, increment]);
      return (/*#__PURE__*/_react.default.cloneElement(children, {
          ref: function ref(node) {
            childRef.current = node;
          }
        })
      );
    };

    exports.AutoFocus = AutoFocus;
    //# sourceMappingURL=AutoFocus.es.js.map
  }
});
//# sourceMappingURL=AutoFocus.es.js.map
